OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "\"config\" დირექტორიაში ჩაწერა ვერ ხერხდება!",
    "See %s" : "იხილეთ %s",
    "Sample configuration detected" : "სანიმუშო კონფუგარცია აღმოჩენილია",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "დადგენილია რომ მოხდა სანიმუშო კონფიგურაციის დაკოპირება. ამან შეიძლება გააფუჭოს თქვენი ინსტალაცია და არაა მხარდაჭერილი. გთხოვთ config.php-ში ცვლილებების შეტანამდე გაეცნოთ დოკუმენტაციას.",
    "%1$s and %2$s" : "%1$s და %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s და %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s და %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s და %5$s",
    "Education Edition" : "საგანმანათლებლო გამოცემა",
    "Enterprise bundle" : "ენტერპრაის კონსტრუქცია",
    "Groupware bundle" : "ჯგუფური კონსტრუქცია",
    "Social sharing bundle" : "სოციალური გაზიარების შეკვრა",
    "PHP %s or higher is required." : "PHP %s ან უფრო მაღალია საჭირო.",
    "PHP with a version lower than %s is required." : "საჭიროა PHP-ს %s-ზე მცირე ვერსია.",
    "%sbit or higher PHP required." : "საჭიროა PHP %s ბიტით ან მეტით.",
    "The command line tool %s could not be found" : "command-line ხელსაწყო %s ვერ იქნა ნაპოვნი",
    "The library %s is not available." : "ბიბლიოთეკა %s ვერ იქნა ნაპოვნი.",
    "Server version %s or higher is required." : "საჭიროა სერვერი ვერსიით %s ან მეტი.",
    "Server version %s or lower is required." : "საჭიროა სერვერი ვერსიით %s ან ნაკლები.",
    "Authentication" : "აუტენტიფიკაცია",
    "Unknown filetype" : "ამოუცნობი ფაილის ტიპი",
    "Invalid image" : "არასწორი სურათი",
    "Avatar image is not square" : "ავატარის სურათი არაა კვადრატი",
    "Files" : "ფაილები",
    "today" : "დღეს",
    "tomorrow" : "ხვალ",
    "yesterday" : "გუშინ",
    "_in %n day_::_in %n days_" : ["%n დღეში","%n დღეში"],
    "_%n day ago_::_%n days ago_" : ["%n დღის წინ","%n დღის წინ"],
    "next month" : "შემდეგი თვე",
    "last month" : "გასულ თვეში",
    "_in %n month_::_in %n months_" : ["%n თვეში","%n თვეში"],
    "_%n month ago_::_%n months ago_" : ["%n თვის წინ","%n თვის წინ"],
    "next year" : "შემდეგი წელი",
    "last year" : "გასულ წელს",
    "_in %n year_::_in %n years_" : ["%n წელიწადში","%n წელიწადში"],
    "_%n year ago_::_%n years ago_" : ["%n წლის წინ","%n წლის წინ"],
    "_in %n hour_::_in %n hours_" : ["%n საათში","%n საათში"],
    "_%n hour ago_::_%n hours ago_" : ["%n საათის წინ","%n საათის წინ"],
    "_in %n minute_::_in %n minutes_" : ["%n წუთში","%n წუთში"],
    "_%n minute ago_::_%n minutes ago_" : ["%n წუთის წინ","%n წუთის წინ"],
    "in a few seconds" : "რამდენიმე წამში",
    "seconds ago" : "წამის წინ",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "მოდული ID-ით: %s არ არსებობს. გთხოვთ აამოქმედოთ ის აპლიკაციების პარამეტრებში ან დაუკავშირდეთ ადმინისტრატორს.",
    "File already exists" : "ფაილი უკვე არსებობს",
    "File name is a reserved word" : "ფაილის სახელი რეზერვირებული სიტყვაა",
    "File name contains at least one invalid character" : "ფაილის სახელი მოიცავს დაუშვებელ სიმბოლოს",
    "File name is too long" : "ფაილის სახელი ზედმეტად გრძელია",
    "Dot files are not allowed" : "წერტილოვანი ფაილები არაა ნებადართლი",
    "Empty filename is not allowed" : "ცარიელი ფაილის სახელი არაა ნებადართული",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "აპლიკაცია \"%s\" ვერ ყენდება, რადგან appinfo ფაილი არ იკითხება.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "აპლიკაცია \"%s\" ვერ ყენდება, რადგან ის ამ სერვერის ვერსიასთან არაა თავსებადი.",
    "__language_name__" : "ქართული",
    "This is an automatically sent email, please do not reply." : "ეს ელ-წერილი გამოგზავნილია ავტომატურად, გთხოვთ არ უპასუხოთ.",
    "Help" : "დახმარება",
    "Apps" : "აპლიკაციები",
    "Settings" : "პარამეტრები",
    "Log out" : "გასვლა",
    "Users" : "მომხმარებლები",
    "Email" : "ელ-ფოსტა",
    "Phone" : "ტელეფონი",
    "Twitter" : "Twitter-ი",
    "Website" : "ვებ-საიტი",
    "Address" : "მისამართი",
    "Profile picture" : "პროფილის სურათი",
    "About" : "შესახებ",
    "Additional settings" : "დამატებითი პარამეტრები",
    "You need to enter details of an existing account." : "საჭიროა შეიყვანოთ არსებული ანგარიშის დეტალები.",
    "Oracle connection could not be established" : "Oracle კავშირი ვერ დამყარდა",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X არაა მხარდაჭერილი და %s ამ პლატფორმაზე სწორად არ იმუშავებს. გამოიყენეთ საკუთარი რისკით!",
    "For the best results, please consider using a GNU/Linux server instead." : "საუკეთესო შედეგებისთვის სანაცვლოდ გამოიყენეთ GNU/Linux სერვერი.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "როგორც ჩანს ეს %s ინსტანცია მოქმედებს 32-ბიტიან PHP გარემოზე და open_basedir php.ini-ში კონფიგურირებულია. ეს 4 გბ-ზე დიდ ფაილებთან გამოიწვევს პრობლემს და რეკომედირებული არაა.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "გთხოვთ ამოშალოთ open_basedir პარამეტრი php.ini-დან ან გადახვიდეთ 64-ბიტიან PHP-ზე.",
    "Set an admin password." : "დააყენეთ ადმინისტრატორის პაროლი.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "გაზიარების ბექენდმა %s-მ მოქმედებაში უნდა მოიყვანოს ინტეფეისი OCP\\Share_Backend",
    "Sharing backend %s not found" : "გაზიარების ბექენდი %s ვერ იქნა ნაპოვნი",
    "Sharing backend for %s not found" : "გაზიარების ბექენდი %s-თვის ვერ იქნა ნაპოვნი",
    "Open »%s«" : "გახნსნა »%s«",
    "You are not allowed to share %s" : "თქვენ არ გაქვთ უფლება გააზიაროთ %s",
    "Cannot increase permissions of %s" : "%s-ის უფლებების გაზრდა ვერ ხერხდება",
    "Expiration date is in the past" : "ვადის ამოწურვის თარიღი წარსულშია",
    "Click the button below to open it." : "გასახსნელად დააჭირეთ ქვემოთ მყოფ ღილაკს.",
    "The requested share does not exist anymore" : "მოთხოვნილი გაზიარება მეტი აღარ არსებობს",
    "Could not find category \"%s\"" : "\"%s\" კატეგორიის მოძებნა ვერ მოხერხდა",
    "Sunday" : "კვირა",
    "Monday" : "ორშაბათი",
    "Tuesday" : "სამშაბათი",
    "Wednesday" : "ოთხშაბათი",
    "Thursday" : "ხუთშაბათი",
    "Friday" : "პარასკევი",
    "Saturday" : "შაბათი",
    "Sun." : "კვი.",
    "Mon." : "ორშ.",
    "Tue." : "სამ.",
    "Wed." : "ოთხ.",
    "Thu." : "ხუთ.",
    "Fri." : "პარ.",
    "Sat." : "შაბ.",
    "Su" : "კვ",
    "Mo" : "ორ",
    "Tu" : "სა",
    "We" : "ოთ",
    "Th" : "ხუ",
    "Fr" : "პა",
    "Sa" : "შა",
    "January" : "იანვარი",
    "February" : "თებერვალი",
    "March" : "მარტი",
    "April" : "აპრილი",
    "May" : "მაისი",
    "June" : "ივნისი",
    "July" : "ივლისი",
    "August" : "აგვისტო",
    "September" : "სექტემბერი",
    "October" : "ოქტომბერი",
    "November" : "ნოემბერი",
    "December" : "დეკემბერი",
    "Jan." : "იან.",
    "Feb." : "თებ.",
    "Mar." : "მარ.",
    "Apr." : "აპრ.",
    "May." : "მაი.",
    "Jun." : "ივნ.",
    "Jul." : "ივლ.",
    "Aug." : "აგვ.",
    "Sep." : "სექ.",
    "Oct." : "ოქტ.",
    "Nov." : "ნოე.",
    "Dec." : "დეკ.",
    "A valid password must be provided" : "უნდა მიუთითოთ სწორი პაროლი",
    "Login canceled by app" : "აპლიკაციამ ლოგინი უარყო",
    "a safe home for all your data" : "უსაფრთხო სახლი მთელი თქვენი მონაცემებისათვის",
    "File is currently busy, please try again later" : "ფაილი ამჟამად დაკავებულია, გთხოვთ მოგვიანებით სცადოთ ახლიდან",
    "Application is not enabled" : "აპლიკაცია არ არის აქტიური",
    "Authentication error" : "აუტენტიფიკაციის შეცდომა",
    "Token expired. Please reload page." : "ტოკენს ვადა გაუვიდა. გთხოვთ განაახლოთ გვერდი.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "მონაცემთა ბაზის დრაივერები (sqlite, mysql, ან postgresql) დაყენებული არაა.",
    "PHP module %s not installed." : "PHP მოდული %s არაა დაყენებული.",
    "Please ask your server administrator to install the module." : "გთხოვთ სთხოვოთ თქვენს სერვერის ადმინისტრატორს დააყენოს მოდული.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP პარამეტრი \"%s\" არ არის დაყენებული \"%s\"-ზე.",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "ამ პარამეტრის დაყენება php.ini-ში Nextcloud-ს გაუშვებს ახლიდან",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "როგორც ჩანს PHP დაყენებულია ისე, რომ შიდა დოკუმენტური ბლოკები წაშალოს. ეს რამდენიმე მთავარ აპლიკაციას გახდის მიუწვდომელს.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "ეს შესაძლოა გამოწვეული იყოს ისეთი კეშით/აქსელერატორით როგორიცაა Zend OPcache ან eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP მოდულები დაყენდა, მაგრამ მაინც ჩამოწერილია როგორც არმყოფები?",
    "Please ask your server administrator to restart the web server." : "გთხოვთ სთხოვოთ თქვენს სერვერის ადმინისტრატორს გადატვირთოს ვებ-სერვერი.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "დარწმუნდით რომ ფაილი სახელად \".ocdata\" მონაცემების დირექტორიის საწყისშია.",
    "Could not obtain lock type %d on \"%s\"." : "ჩაკეთვის ტიპის %d მოძიება \"%s\"-ზე ვერ მოხერხდა.",
    "Storage unauthorized. %s" : "საცავი არაავტორიზირებულია. %s",
    "Storage incomplete configuration. %s" : "საცავის არასრული კონფიგურაცია. %s",
    "Storage connection error. %s" : "საცავის კავშირის შეცდომა. %s",
    "Storage is temporarily not available" : "საცავი დროებით ხელმიუწვდომელია",
    "Storage connection timeout. %s" : "საცავის კავშირის დროის ამოწურვა. %s",
    "Logged in user must be an admin" : "ავტორიზირებული მომხმარებელი უნდა იყოს ადმინისტრატორი",
    "Full name" : "სრული სახელი",
    "Unknown user" : "ამოუცნობი მომხმარებელი",
    "Oracle username and/or password not valid" : "Oracle მომხმარებლის სახელი და/ან პაროლი არ არის სწორი",
    "PostgreSQL username and/or password not valid" : "PostgreSQL მომხმარებლის სახელი და/ან პაროლი არ არის სწორი",
    "Set an admin username." : "დააყენეთ ადმინისტრატორის სახელი.",
    "Sharing %s failed, because this item is already shared with user %s" : "%s-ის გაზიარება არ მოხერხდა, რადგან ობიექტი მომხმარებელ %s-თან უკვე გაზიარებულია",
    "The username is already being used" : "ესეთი მომხმარებლის სახელი უკვე არსებობს",
    "Could not create user" : "მომხმარებლის შექმნა ვერ მოხერხდა",
    "A valid username must be provided" : "უნდა მიუთითოთ არსებული მომხმარებლის სახელი",
    "Username contains whitespace at the beginning or at the end" : "მომხმარებლის სახელი დასაწყისსში ან დასასრულში მოიცავს სიცარიელეს",
    "Username must not consist of dots only" : "მომხმარებლის სახელი ვერ იქნება შემდგარი მხოლოდ წერტილებისგან",
    "User disabled" : "მომხმარებელი გათიშულია",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "საჭიროა libxml2 ვერსიით 2.7.0 ან მეტი. ახლა დაყენებულია %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "ამ პრობლემის მოსაგვარებლად განაახლეთ libxml2 ვერსია და გადატვირთეთ თქვენი ვებ-სერვერი.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "გთხოვთ შეცვალოთ უფლებები 0770-ზე, რათა დირექტორია სხვა მომხმარებლების მიერ აღარ იყოს კითხვადი."
},
"nplurals=2; plural=(n!=1);");
